#!/usr/bin/env bash

>&2 echo "DESTRUCTIVE!!! Syncing local WordPress database to dev."

## Exit if pipe fails ##
set -o pipefail

## Source scripts
vendor_brewpixel_barista_bin_wp_dir=$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )

source "${vendor_brewpixel_barista_bin_wp_dir}/../../Burr/burr-dependencies.sh"
ensure_readlink_installed

if [[ "$OSTYPE" == "linux-gnu" ]]; then
    vendor_brewpixel_barista_bin_dir=$(readlink -f $(dirname "${vendor_brewpixel_barista_bin_wp_dir}"))
	vendor_brewpixel_barista_dir=$(readlink -f $(dirname "${vendor_brewpixel_barista_bin_dir}"))
	vendor_brewpixel_dir=$(readlink -f $(dirname "${vendor_brewpixel_barista_dir}"))
	vendor_dir=$(readlink -f $(dirname "${vendor_brewpixel_dir}"))
	project_base=$(readlink -f $(dirname "${vendor_dir}"))
elif [[ "$OSTYPE" == "darwin"* ]]; then
	# Mac OSX
	vendor_brewpixel_barista_bin_dir=$(greadlink -f $(dirname "${vendor_brewpixel_barista_bin_wp_dir}"))
	vendor_brewpixel_barista_dir=$(greadlink -f $(dirname "${vendor_brewpixel_barista_bin_dir}"))
	vendor_brewpixel_dir=$(greadlink -f $(dirname "${vendor_brewpixel_barista_dir}"))
	vendor_dir=$(greadlink -f $(dirname "${vendor_brewpixel_dir}"))
	project_base=$(greadlink -f $(dirname "${vendor_dir}"))
else
    # Unknown.
    vendor_brewpixel_barista_bin_dir=$(readlink -f $(dirname "${vendor_brewpixel_barista_bin_wp_dir}"))
	vendor_brewpixel_barista_dir=$(readlink -f $(dirname "${vendor_brewpixel_barista_bin_dir}"))
	vendor_brewpixel_dir=$(readlink -f $(dirname "${vendor_brewpixel_barista_dir}"))
	vendor_dir=$(readlink -f $(dirname "${vendor_brewpixel_dir}"))
	project_base=$(readlink -f $(dirname "${vendor_dir}"))
fi

## Source scripts
source "${vendor_brewpixel_barista_dir}/config.sh"
source "${vendor_brewpixel_barista_dir}/Burr/bootstrap.sh"

#source "${vendor_brewpixel_barista_dir}/../bashful/bin/bashful"

for f in $(ls "${vendor_brewpixel_barista_dir}/Burr/");
    do source "${vendor_brewpixel_barista_dir}/Burr/${f}";
done

>&2 echo "/srv/www/alpha.tf/${main_repo_name}"
cd "/srv/www/alpha.tf/${main_repo_name}"

# Before continuing, check that the database prefix matches local
db_prefix_local=$(cd "${project_base}" && wp db prefix)
db_prefix_dev=$(ssh ${sshuser}@${sship} "cd "/srv/www/alpha.tf/${main_repo_name}" && wp db prefix")
>&2 echo "$db_prefix_dev"
>&2 echo "$db_prefix_local"
if [ "$db_prefix_dev" = "$db_prefix_local" ]; then
    >&2 echo "Dev and local database table prefixes match."
else
    die "Dev and local database table prefixes do not match. Please fix this so they match before attempting to synchronise them again."
fi

today=$(date +"%Y-%m-%d")

# Backup, Drop and Create dev database
ssh ${sshuser}@${sship} "cd "/srv/www/alpha.tf/${main_repo_name}" && wp db export --single-transaction --opt --quote-names --complete-insert --compress "/srv/www/alpha.tf/${main_repo_name}"/public_html/content/${today}-${main_repo_name}.sql && wp db reset --yes"

#eval "$(parse_yaml "${project_base}")"
#>&2 echo "Location of Local WordPress: $path"
#>&2 echo "SSH user: $sshuser"
#>&2 echo "SSH IP: $sship"
#
#eval "$(parse_yaml "/srv/www/alpha.tf/${main_repo_name}/wp-cli.yml")"
#>&2 echo "Location of Staging WordPress: $path"

### Export local database. Import local database file into dev database ###
# @TODO How do we export locally and import on remote server?
cd "${project_base}" && wp db export --single-transaction --opt --quote-names --complete-insert --compress - | ssh ${sshuser}@${sship} "wp db import --path="/srv/www/alpha.tf/${main_repo_name}/public_html/wp" -"

# Search and replace local URLs to dev
ssh ${sshuser}@${sship} "cd "/srv/www/alpha.tf/${main_repo_name}" && wp search-replace "${main_repo_name}.local" "${main_repo_name}.alpha.tf" --skip-columns=guid --all-tables
wp search-replace "www.${main_repo_name}" "${main_repo_name}" --skip-columns=guid --all-tables
wp search-replace "${main_repo_name}.alpha.tf/wp-content" "${main_repo_name}.alpha.tf/content" --skip-columns=guid --all-tables
wp search-replace "${main_repo_name}.alpha.tf\/wp-content" "${main_repo_name}.alpha.tf\/content" --skip-columns=guid --all-tables
wp search-replace "${main_repo_name}.alpha.tf%2Fwp-content" "${main_repo_name}.alpha.tf%2Fcontent" --skip-columns=guid --all-tables
wp search-replace 'wp-content/uploads' 'content/uploads' --skip-columns=guid --all-tables
wp search-replace 'wp-content\/uploads' 'content\/uploads' --skip-columns=guid --all-tables
wp option update blog_public 0"

>&2 echo "Finished syncing local WordPress database to dev."
